searchData={"items":[{"type":"module","title":"Charex","doc":"This library mostly wraps the Charabia library from Rust.\n\n- [docs](https://docs.rs/charabia/latest/charabia/)\n- [crate](https://crates.io/crates/charabia)\n- [github](https://github.com/meilisearch/charabia)\n\nThis library mostly just calls that library, and passes the response back through to Elixir.\n\nThe only slight changes are that the scripts have been converted to their (closest) ISO codes:\n\n- `Latin` to `latn`\n- `Greek` to `grek`\n- `Arabic` to `arab`\n- etc.\n\nThe languages have been converted from 3 letter codes to 2 letter ISO codes, mostly because this is the form I needed them in.\n\n- `eng` to `en`\n- `spa` to `es`\n- `cmn` to `zh`\n- etc.","ref":"Charex.html"},{"type":"module","title":"Some caveats/notes: - Charex","doc":"#","ref":"Charex.html#module-some-caveats-notes"},{"type":"module","title":"Hans / Hant - Charex","doc":"- The original library doesn't distinguish between simplified or traditional chinese, and tags them all as just CJ(chinese/japanese) for the script, and CMN for the language. On the Elixir side, you will see, `:zh` for the language, and `:hans` for the script.\n\n#","ref":"Charex.html#module-hans-hant"},{"type":"module","title":"Jpan / Hans - Charex","doc":"- The original library combines Chinese/Han and Japanese scripts into CJ which doesn't have a direct ISO code. However the Rust lib does usually correctly tag the language. Currently if the language is correctly tagged as `Language::Jpn`/`:ja` then the script will correctly be tagged as `:jpan`. However, if the language isn't tagged correctly as Japanese, the script will fallback to `:hans`.\n\n#","ref":"Charex.html#module-jpan-hans"},{"type":"module","title":"Disclaimer - Charex","doc":"Those choice to use `:hans` instead of `:hant` was chosen purely based on number of speakers, and is in no way intended as a political statement.","ref":"Charex.html#module-disclaimer"},{"type":"function","title":"Charex.segmentize/1","doc":"A slightly faster version that segments the string into a list of strings.\n\n```elixir\niex> segmentize(\"This is an example.\")\n[\"This\", \" \", \"is\", \" \", \"an\", \" \", \"example\", \".\"]\niex> segmentize(\"これは一例です。\")\n[\"これ\", \"は\", \"一\", \"例\", \"です\", \"。\"]\niex> segmentize(\"这是一个例子。\")\n[\"这\", \"是\", \"一个\", \"例子\", \"。\"]\n```","ref":"Charex.html#segmentize/1"},{"type":"function","title":"Charex.tokenize/1","doc":"Tokenizes a string into a list of `Charex.Token` structs.\n\n```elixir\niex> tokenize(\"This is an example.\")\n[%Charex.Token{kind: :word, lemma: \"this\", char_start: 0, char_end: 4, byte_start: 0, byte_end: 4, char_map: nil, script: :latn, language: :other}, ...]\niex> tokenize(\"これは一例です。\")\n[%Charex.Token{ kind: :word, lemma: \"これ\", char_start: 0, char_end: 2, byte_start: 0, byte_end: 6, char_map: nil, script: :jpan, language: :ja}, ...]\niex> tokenize(\"这是一个例子。\")\n[%Charex.Token{kind: :word, lemma: \"zhè\", char_start: 0, char_end: 1, byte_start: 0, byte_end: 3, char_map: nil, script: :hans, language: :zh}, ...]\niex> tokenize(\"이것은 예입니다.\")\n[%Charex.Token{kind: :word, lemma: \"이것\", char_start: 0, char_end: 2, byte_start: 0, byte_end: 6, char_map: nil, script: :hang, language: :ko}, %Charex.Token{kind: :word, lemma: \"은\", ...}, ...]\n```","ref":"Charex.html#tokenize/1"},{"type":"module","title":"Charex.Token","doc":"Wrapper of the Charabia Token.","ref":"Charex.Token.html"},{"type":"module","title":"Notes: - Charex.Token","doc":"### `char_map`\nseems to always be nil from what I can tell, but there might be some languages that use it, so it's here for compatibility, but don't be surprised if it's nil for you.\n### `char_start`/`char_end`\nThese are not really characters as we may commonly think of them(which are actually called grapheme clusters in Unicode).\n`String.length/1` in Elixir for example counts grapheme clusters, which is different than what this range is counting, which is codepoint indexes.\nFor example `\"👨‍👩‍👧‍👦\"` would have a `start`/`end` that is 7 numbers apart instead of 1 number apart.\nThis is the same as you'd get from `String.codepoints/1`, or `to_charlist/1`\n### `byte_start`/`byte_end`\nThese are as you'd expect, byte offsets, and could be used to slice the string with `:binary.part/3`, but *NOT* with `String.slice/3`(if you use this function it may appear to work for latin/ascii characters, but will break your code as soon as non-ascii characters are used. `:binary.part/3` is the correct function to use)","ref":"Charex.Token.html#module-notes"},{"type":"function","title":"Charex.Token.all_langs/0","doc":"Returns a list of all 70 of the language values used in the `language` key","ref":"Charex.Token.html#all_langs/0"},{"type":"function","title":"Charex.Token.all_scripts/0","doc":"Returns a list of all 25 of the script values used in the `script` key","ref":"Charex.Token.html#all_scripts/0"},{"type":"type","title":"Charex.Token.lang/0","doc":"","ref":"Charex.Token.html#t:lang/0"},{"type":"type","title":"Charex.Token.script/0","doc":"","ref":"Charex.Token.html#t:script/0"},{"type":"type","title":"Charex.Token.t/0","doc":"","ref":"Charex.Token.html#t:t/0"},{"type":"extras","title":"Charex","doc":"# Charex\n\nElixir NIF wrapper of the Rust Charabia string tokenization/segmentation library","ref":"readme.html"},{"type":"extras","title":"Installation - Charex","doc":"The package can be installed\nby adding `charex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:charex, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Charex","doc":"```elixir\niex> Charex.tokenize(\"これは一例です。\")\n[\n  %Charex.Token{\n    kind: :word,\n    lemma: \"これ\",\n    char_start: 0,\n    char_end: 2,\n    byte_start: 0,\n    byte_end: 6,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  },\n  %Charex.Token{\n    kind: :word,\n    lemma: \"は\",\n    char_start: 2,\n    char_end: 3,\n    byte_start: 6,\n    byte_end: 9,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  },\n  %Charex.Token{\n    kind: :word,\n    lemma: \"一\",\n    char_start: 3,\n    char_end: 4,\n    byte_start: 9,\n    byte_end: 12,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  },\n  %Charex.Token{\n    kind: :word,\n    lemma: \"例\",\n    char_start: 4,\n    char_end: 5,\n    byte_start: 12,\n    byte_end: 15,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  },\n  %Charex.Token{\n    kind: :word,\n    lemma: \"です\",\n    char_start: 5,\n    char_end: 7,\n    byte_start: 15,\n    byte_end: 21,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  },\n  %Charex.Token{\n    kind: {:separator, :hard},\n    lemma: \"。\",\n    char_start: 7,\n    char_end: 8,\n    byte_start: 21,\n    byte_end: 24,\n    char_map: nil,\n    script: :jpan,\n    language: :ja\n  }\n]\n\niex> Charex.segmentize(\"这是一个例子。\")\n[\"这\", \"是\", \"一个\", \"例子\", \"。\"]\n\n```","ref":"readme.html#usage"},{"type":"extras","title":"Benchmarks - Charex","doc":"These are all roughly 100 byte strings. These are not the only supported languages, but just a mixture to show some rough results.\n\n```\nOperating System: macOS\nCPU Information: Apple M1 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.16.0\nErlang 26.2.1\nJIT enabled: true\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 5 s\nmemory time: 1 s\nreduction time: 1 s\nparallel: 1\ninputs: none specified\nEstimated total run time: 1 min 30 s\n\nBenchmarking tokenize_ja ...\nBenchmarking segmentize_ja ...\nBenchmarking tokenize_zh ...\nBenchmarking segmentize_zh ...\nBenchmarking tokenize_en ...\nBenchmarking segmentize_en ...\nBenchmarking tokenize_ko ...\nBenchmarking segmentize_ko ...\nBenchmarking tokenize_ar ...\nBenchmarking segmentize_ar ...\nCalculating statistics...\nFormatting results...\n\nName                    ips        average  deviation         median         99th %\nsegmentize_ar      215.97 K        4.63 μs   ±749.72%        3.50 μs        5.71 μs\nsegmentize_en      141.26 K        7.08 μs   ±566.37%        5.21 μs        9.33 μs\nsegmentize_zh      121.84 K        8.21 μs   ±247.33%        7.29 μs           9 μs\ntokenize_ar         84.90 K       11.78 μs   ±101.33%       10.88 μs       23.88 μs\ntokenize_en         58.16 K       17.19 μs    ±50.91%       15.92 μs       44.17 μs\nsegmentize_ja       58.12 K       17.21 μs    ±88.31%       16.42 μs       25.17 μs\ntokenize_zh         55.84 K       17.91 μs    ±47.74%       16.96 μs       58.08 μs\nsegmentize_ko       49.17 K       20.34 μs   ±103.65%       19.25 μs       32.08 μs\ntokenize_ja         39.60 K       25.25 μs    ±35.18%       24.25 μs       54.92 μs\ntokenize_ko         32.28 K       30.97 μs    ±17.23%       30.13 μs       49.46 μs\n\nComparison:\nsegmentize_ar      215.97 K\nsegmentize_en      141.26 K - 1.53x slower +2.45 μs\nsegmentize_zh      121.84 K - 1.77x slower +3.58 μs\ntokenize_ar         84.90 K - 2.54x slower +7.15 μs\ntokenize_en         58.16 K - 3.71x slower +12.56 μs\nsegmentize_ja       58.12 K - 3.72x slower +12.58 μs\ntokenize_zh         55.84 K - 3.87x slower +13.28 μs\nsegmentize_ko       49.17 K - 4.39x slower +15.71 μs\ntokenize_ja         39.60 K - 5.45x slower +20.62 μs\ntokenize_ko         32.28 K - 6.69x slower +26.34 μs\n\nMemory usage statistics:\n\nName             Memory usage\nsegmentize_ar         1.64 KB\nsegmentize_en         1.64 KB - 1.00x memory usage +0 KB\nsegmentize_zh         1.64 KB - 1.00x memory usage +0 KB\ntokenize_ar           1.64 KB - 1.00x memory usage +0 KB\ntokenize_en           1.64 KB - 1.00x memory usage +0 KB\nsegmentize_ja         1.64 KB - 1.00x memory usage +0 KB\ntokenize_zh           1.66 KB - 1.01x memory usage +0.0234 KB\nsegmentize_ko         1.65 KB - 1.00x memory usage +0.00781 KB\ntokenize_ja           1.63 KB - 0.99x memory usage -0.01563 KB\ntokenize_ko           1.66 KB - 1.01x memory usage +0.0156 KB\n\n**All measurements for memory usage were the same**\n\nReduction count statistics:\n\nName          Reduction count\nsegmentize_ar              13\nsegmentize_en              32 - 2.46x reduction count +19\nsegmentize_zh              18 - 1.38x reduction count +5\ntokenize_ar                85 - 6.54x reduction count +72\ntokenize_en               146 - 11.23x reduction count +133\nsegmentize_ja              19 - 1.46x reduction count +6\ntokenize_zh                97 - 7.46x reduction count +84\nsegmentize_ko              16 - 1.23x reduction count +3\ntokenize_ja               101 - 7.77x reduction count +88\ntokenize_ko                92 - 7.08x reduction count +79\n\n**All measurements for reduction count were the same**\n```","ref":"readme.html#benchmarks"},{"type":"extras","title":"CHANGELOG.md","doc":"# CHANGELOG.md","ref":"changelog.html"},{"type":"extras","title":"0.4.0 (2024-01-30) - CHANGELOG.md","doc":"Features:\n\n  - Rustler Precompiled working","ref":"changelog.html#0-4-0-2024-01-30"},{"type":"extras","title":"0.1.0 (2024-01-29) - CHANGELOG.md","doc":"Features:\n\n  - Initial commit","ref":"changelog.html#0-1-0-2024-01-29"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Peter Richards\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}